searchNodes=[{"doc":"ExLiveUrl is just some simple Phoenix LiveView lifecycle hooks and helper functions. It helps you store the live view's current query params and path in your assigns. Additionally, it exposes ways to work with those values both synchronously (only from the root live view) and asynchronously (from anywhere). Installation You can install ExLiveUrl like so: defp deps do [ { :ex_live_url , &quot;~&gt; 0.2.0&quot; } ] end To use ExLiveUrl you will need to call Phoenix.LiveView.on_mount/1 with the module, ExLiveUrl in your live view. For example: defmodule YourLiveView do use Phoenix.LiveView on_mount ExLiveUrl # your live view implementation end Example A common use case for url state in live views is to store sorting and filtering information. Here's a working example of how you can implement such a use case with ExLiveUrl . iex&gt; defmodule Example.SortControl do ...&gt; use Phoenix.LiveComponent ...&gt; ...&gt; @impl Phoenix.LiveComponent ...&gt; def render ( assigns ) do ...&gt; ~H&quot;&quot;&quot; ...&gt; &lt;button phx-click=&quot;toggle&quot; phx-target={@myself}&gt; ...&gt; &lt;%= @direction || &quot;sort&quot; %&gt; ...&gt; &lt;/button&gt; ...&gt; &quot;&quot;&quot; ...&gt; end ...&gt; ...&gt; @impl Phoenix.LiveComponent ...&gt; def handle_event ( &quot;toggle&quot; , _payload , socket ) do ...&gt; :ok = ExLiveUrl . send_operation ( fn url -&gt; ...&gt; ExLiveUrl.Operation . push_patch ( to : ExLiveUrl.Url . with_params ( url , fn params -&gt; ...&gt; Map . update ( params , &quot;direction&quot; , &quot;asc&quot; , fn ...&gt; &quot;asc&quot; -&gt; &quot;desc&quot; ...&gt; &quot;desc&quot; -&gt; &quot;asc&quot; ...&gt; end ) ...&gt; end ) ) ...&gt; end ) ...&gt; ...&gt; { :noreply , socket } ...&gt; end ...&gt; end iex&gt; defmodule Example.LiveView do ...&gt; use Phoenix.LiveView ...&gt; on_mount ExLiveUrl ...&gt; ...&gt; @impl Phoenix.LiveView ...&gt; def render ( assigns ) do ...&gt; ~H&quot;&quot;&quot; ...&gt; &lt;.live_component module={Example.SortControl} id=&quot;Example.SortControl&quot; direction={@direction} /&gt; ...&gt; &lt;p :for={name &lt;- @names}&gt;&lt;%= name %&gt;&lt;/p&gt; ...&gt; &quot;&quot;&quot; ...&gt; end ...&gt; ...&gt; @impl Phoenix.LiveView ...&gt; def mount ( _params , _session , socket ) do ...&gt; { :ok , assign ( socket , :names , [ &quot;John&quot; , &quot;Jimmy&quot; , &quot;Jack&quot; , &quot;Joe&quot; ] ) } ...&gt; end ...&gt; ...&gt; @impl Phoenix.LiveView ...&gt; def handle_params ( params , _uri , socket ) do ...&gt; { :ok , ...&gt; socket ...&gt; |&gt; assign ( :direction , params [ &quot;direction&quot; ] ) ...&gt; |&gt; update ( ...&gt; :names , ...&gt; fn names -&gt; ...&gt; case params [ &quot;direction&quot; ] do ...&gt; &quot;desc&quot; -&gt; Enum . sort ( names , fn name_1 , name_2 -&gt; name_1 &lt;= name_2 end ) ...&gt; &quot;asc&quot; -&gt; Enum . sort ( names , fn name_1 , name_2 -&gt; name_1 &gt;= name_2 end ) ...&gt; nil -&gt; names ...&gt; end ...&gt; end ...&gt; ) } ...&gt; end ...&gt; end","ref":"ExLiveUrl.html","title":"ExLiveUrl","type":"module"},{"doc":"Tip: This function may only be called with the root live view's socket. If you need to, for example, call this from a live component, you should use send_operation/2 . Synchronously build and apply an operation. The build function takes the current ExLiveUrl.Url as an argument and must return an ExLiveUrl.Operation . The given pid must be a root live view. This is an alias for ExLiveUrl.Operation.apply/2 .","ref":"ExLiveUrl.html#apply_operation/2","title":"ExLiveUrl.apply_operation/2","type":"function"},{"doc":"A special case of send_operation/2 which uses self() as the given pid.","ref":"ExLiveUrl.html#send_operation/1","title":"ExLiveUrl.send_operation/1","type":"function"},{"doc":"Asynchronously build and apply an operation. The build function takes the current ExLiveUrl.Url as an argument and must return an ExLiveUrl.Operation . The given pid must be a root live view.","ref":"ExLiveUrl.html#send_operation/2","title":"ExLiveUrl.send_operation/2","type":"function"},{"doc":"ExLiveUrl.Operation structs represent url operations. An operation consists of a :url which the operation targets, a :mode which indicates how the server should get to the target (updating the current view, mounting a new view, or going to an external url), and a :stack_operation which indicates how applying the operation should update the browser's history stack (pushing a history entry, replacing the current history entry, or updating window.location entirely).","ref":"ExLiveUrl.Operation.html","title":"ExLiveUrl.Operation","type":"module"},{"doc":"Apply an operation to the given socket. iex&gt; socket = % Phoenix.LiveView.Socket { ...&gt; assigns : %{ ...&gt; :__changed__ =&gt; %{ } , ...&gt; ExLiveUrl =&gt; ExLiveUrl.Url . from_string ( &quot;http://apple.com&quot; ) ...&gt; } ...&gt; } iex&gt; ExLiveUrl.Operation . apply ( socket , ExLiveUrl.Operation . redirect ( external : &quot;https://google.com&quot; ) ) % Phoenix.LiveView.Socket { assigns : %{ :__changed__ =&gt; %{ } , ExLiveUrl =&gt; % ExLiveUrl.Url { scheme : :http , host : &quot;apple.com&quot; , port : 80 , path : &quot;/&quot; , params : %{ } } } , redirected : { :redirect , %{ external : &quot;https://google.com:443/?&quot; } } }","ref":"ExLiveUrl.Operation.html#apply/2","title":"ExLiveUrl.Operation.apply/2","type":"function"},{"doc":"Build a push navigate operation. iex&gt; ExLiveUrl.Operation . push_navigate ( to : ExLiveUrl.Url . from_string ( &quot;https://google.com&quot; ) ) % ExLiveUrl.Operation { url : % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/&quot; , params : %{ } } , mode : :inter_view , stack_operation : :push } iex&gt; ExLiveUrl.Operation . push_navigate ( to : ExLiveUrl.Url . from_string ( &quot;https://google.com&quot; ) , replace : true ) % ExLiveUrl.Operation { url : % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/&quot; , params : %{ } } , mode : :inter_view , stack_operation : :replace }","ref":"ExLiveUrl.Operation.html#push_navigate/1","title":"ExLiveUrl.Operation.push_navigate/1","type":"function"},{"doc":"Build a push patch operation. iex&gt; ExLiveUrl.Operation . push_patch ( to : ExLiveUrl.Url . from_string ( &quot;https://google.com&quot; ) ) % ExLiveUrl.Operation { url : % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/&quot; , params : %{ } } , mode : :intra_view , stack_operation : :push } iex&gt; ExLiveUrl.Operation . push_patch ( to : ExLiveUrl.Url . from_string ( &quot;https://google.com&quot; ) , replace : true ) % ExLiveUrl.Operation { url : % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/&quot; , params : %{ } } , mode : :intra_view , stack_operation : :replace }","ref":"ExLiveUrl.Operation.html#push_patch/1","title":"ExLiveUrl.Operation.push_patch/1","type":"function"},{"doc":"Build a redirect operation. iex&gt; ExLiveUrl.Operation . redirect ( to : ExLiveUrl.Url . from_string ( &quot;https://google.com&quot; ) ) % ExLiveUrl.Operation { url : % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/&quot; , params : %{ } } , mode : :inter_view , stack_operation : :redirect } iex&gt; ExLiveUrl.Operation . redirect ( external : &quot;https://google.com&quot; ) % ExLiveUrl.Operation { url : % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/&quot; , params : %{ } } , mode : :external , stack_operation : :redirect } iex&gt; ExLiveUrl.Operation . redirect ( external : ExLiveUrl.Url . from_string ( &quot;https://google.com&quot; ) ) % ExLiveUrl.Operation { url : % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/&quot; , params : %{ } } , mode : :external , stack_operation : :redirect }","ref":"ExLiveUrl.Operation.html#redirect/1","title":"ExLiveUrl.Operation.redirect/1","type":"function"},{"doc":"","ref":"ExLiveUrl.Operation.html#t:t/0","title":"ExLiveUrl.Operation.t/0","type":"type"},{"doc":"ExLiveUrl.Url structs represent fully qualified urls. You can think of them as bespoke URI structs.","ref":"ExLiveUrl.Url.html","title":"ExLiveUrl.Url","type":"module"},{"doc":"This function turns a string into a ExLiveUrl.Url . The given string must be absolute url. iex&gt; ExLiveUrl.Url . from_string ( &quot;https://google.com/abc?a[]=b&amp;a[]=c&quot; ) % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/abc&quot; , params : %{ &quot;a&quot; =&gt; [ &quot;b&quot; , &quot;c&quot; ] } }","ref":"ExLiveUrl.Url.html#from_string/1","title":"ExLiveUrl.Url.from_string/1","type":"function"},{"doc":"This function turns a URI into a ExLiveUrl.Url . The given URI must be absolute. iex&gt; ExLiveUrl.Url . from_uri ( ...&gt; % URI { ...&gt; scheme : &quot;https&quot; , ...&gt; host : &quot;google.com&quot; , ...&gt; port : 443 , ...&gt; path : &quot;/abc&quot; , ...&gt; query : &quot;a[]=b&amp;a[]=c&quot; , ...&gt; } ...&gt; ) % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/abc&quot; , params : %{ &quot;a&quot; =&gt; [ &quot;b&quot; , &quot;c&quot; ] } }","ref":"ExLiveUrl.Url.html#from_uri/1","title":"ExLiveUrl.Url.from_uri/1","type":"function"},{"doc":"This function serializes a ExLiveUrl.Url to a relative link, aka just the path and query params. iex&gt; ExLiveUrl.Url . to_relative ( ...&gt; % ExLiveUrl.Url { ...&gt; scheme : :https , ...&gt; host : &quot;google.com&quot; , ...&gt; port : 443 , ...&gt; path : &quot;/abc&quot; , ...&gt; params : %{ &quot;a&quot; =&gt; &quot;b&quot; } ...&gt; } ...&gt; ) &quot;/abc?a=b&quot;","ref":"ExLiveUrl.Url.html#to_relative/1","title":"ExLiveUrl.Url.to_relative/1","type":"function"},{"doc":"This function sets the host of an ExLiveUrl.Url either directly or via an updater function. iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_host ( &quot;apple.com&quot; ) % ExLiveUrl.Url { scheme : :https , host : &quot;apple.com&quot; , port : 443 , path : &quot;/abc&quot; , params : %{ } } iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_host ( fn host -&gt; &quot;www. \#{ host } &quot; end ) % ExLiveUrl.Url { scheme : :https , host : &quot;www.google.com&quot; , port : 443 , path : &quot;/abc&quot; , params : %{ } }","ref":"ExLiveUrl.Url.html#with_host/2","title":"ExLiveUrl.Url.with_host/2","type":"function"},{"doc":"This function sets the params of an ExLiveUrl.Url either directly or via an updater function. iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_params ( %{ &quot;a&quot; =&gt; [ &quot;b&quot; , &quot;c&quot; ] } ) % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/abc&quot; , params : %{ &quot;a&quot; =&gt; [ &quot;b&quot; , &quot;c&quot; ] } } iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_params ( fn params -&gt; Map . put ( params , &quot;a&quot; , [ &quot;b&quot; , &quot;c&quot; ] ) end ) % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/abc&quot; , params : %{ &quot;a&quot; =&gt; [ &quot;b&quot; , &quot;c&quot; ] } }","ref":"ExLiveUrl.Url.html#with_params/2","title":"ExLiveUrl.Url.with_params/2","type":"function"},{"doc":"This function sets the path of an ExLiveUrl.Url either directly or via an updater function. iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_path ( &quot;/&quot; ) % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/&quot; , params : %{ } } iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_path ( fn path -&gt; path &lt;&gt; &quot;/efg&quot; end ) % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 443 , path : &quot;/abc/efg&quot; , params : %{ } }","ref":"ExLiveUrl.Url.html#with_path/2","title":"ExLiveUrl.Url.with_path/2","type":"function"},{"doc":"This function sets the port of an ExLiveUrl.Url either directly or via an updater function. iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_port ( 1234 ) % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 1234 , path : &quot;/abc&quot; , params : %{ } } iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_port ( fn port -&gt; port + 1 end ) % ExLiveUrl.Url { scheme : :https , host : &quot;google.com&quot; , port : 444 , path : &quot;/abc&quot; , params : %{ } }","ref":"ExLiveUrl.Url.html#with_port/2","title":"ExLiveUrl.Url.with_port/2","type":"function"},{"doc":"This function sets the scheme of an ExLiveUrl.Url either directly or via an updater function. iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_scheme ( :http ) % ExLiveUrl.Url { scheme : :http , host : &quot;google.com&quot; , port : 443 , path : &quot;/abc&quot; , params : %{ } } iex&gt; &quot;https://google.com/abc&quot; ...&gt; |&gt; ExLiveUrl.Url . from_string ( ) ...&gt; |&gt; ExLiveUrl.Url . with_scheme ( fn :https -&gt; :http end ) % ExLiveUrl.Url { scheme : :http , host : &quot;google.com&quot; , port : 443 , path : &quot;/abc&quot; , params : %{ } }","ref":"ExLiveUrl.Url.html#with_scheme/2","title":"ExLiveUrl.Url.with_scheme/2","type":"function"},{"doc":"","ref":"ExLiveUrl.Url.html#t:t/0","title":"ExLiveUrl.Url.t/0","type":"type"}]